"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const { cmdOrderCreate, getOrderStore, clearOrderStore, onOrderUpdate, onOrderError, } = require('../orderStore');
const orderServerToolMock_1 = require("../__mocks__/orderServerToolMock");
const authDataProvider_1 = require("../__mocks__/authDataProvider");
const orderTypes_1 = require("../orderTypes");
const ctx = {};
test('create order should add new key to orders map', () => {
    const { id, correlationId } = cmdOrderCreate(ctx, authDataProvider_1.authDataProvider, orderServerToolMock_1.orderServerTool);
    expect(id).toBe('order1');
    expect(correlationId).toBe('corelation1');
    const orderStore = getOrderStore();
    const rec = orderStore['order1'];
    expect(rec).not.toBeNull();
    expect(rec.recStatus).toBe(orderTypes_1.EOrderRecStatus.INITIALIZING);
});
test('invocation of onOrderUpdate (new id) should update orders map', () => {
    onOrderUpdate({
        id: 'order1002',
        tenant: 'tenant1',
        orderType: orderTypes_1.EOrderType.DELIVERY,
        status: orderTypes_1.EOrderStatus.NEW,
        created: new Date('2021-01-01'),
        total: 501,
        buckets: [],
    });
    const orderStore = getOrderStore();
    const rec = orderStore['order1002'];
    expect(rec).not.toBeNull();
    expect(rec.recStatus).toBe(orderTypes_1.EOrderRecStatus.VALID);
});
test('create order, then notification with error -> proper state', () => {
    const { id, correlationId } = cmdOrderCreate(ctx, authDataProvider_1.authDataProvider, orderServerToolMock_1.orderServerTool);
    expect(id).toBe('order2');
    expect(correlationId).toBe('corelation2');
    onOrderError({
        id: 'order2',
        message: 'Unknown error',
    });
    const orderStore = getOrderStore();
    const rec = orderStore['order2'];
    expect(rec).not.toBeNull();
    expect(rec.recStatus).toBe(orderTypes_1.EOrderRecStatus.INVALID);
});
test('create order, update and update with close=true, should add and finaly remove item in the orders map', () => {
    clearOrderStore();
    const { id } = cmdOrderCreate(ctx, authDataProvider_1.authDataProvider, orderServerToolMock_1.orderServerTool);
    expect(id).toBe('order3');
    const orderStore = getOrderStore();
    const rec = orderStore['order3'];
    expect(rec).not.toBeNull();
    expect(Object.keys(orderStore).length).toBe(1);
    onOrderUpdate({
        id: 'order3',
        tenant: 'tenant1',
        orderType: orderTypes_1.EOrderType.DELIVERY,
        status: orderTypes_1.EOrderStatus.NEW,
        created: new Date('2021-01-01'),
        total: 501,
        closed: true,
        buckets: [],
    });
    expect(Object.keys(orderStore).length).toBe(0);
});
