"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setAuthData = exports.authDataProvider = exports.authorizeWithRefreshToken = exports.authorizeWithUserPass = void 0;
const axios_1 = __importDefault(require("axios"));
let _authData;
let tokenRetrieveTimeMs = -1;
function authorizeWithUserPass(baseUrl, tenant, basicAuthPass, username, password) {
    return __awaiter(this, void 0, void 0, function* () {
        let response = null;
        try {
            response = yield axios_1.default({
                method: 'post',
                url: `${baseUrl}/auth-oauth2/oauth/token`,
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
                    Authorization: `Basic ${basicAuthPass}`,
                    'X-Tenant': tenant,
                },
                data: `username=${username}&password=${password}&grant_type=password&scope=read`,
            });
            _authData = response.data;
            tokenRetrieveTimeMs = new Date().getTime();
            return true;
        }
        catch (error) {
            //console.error('Authorization error');
            //console.error(error);
            return false;
        }
    });
}
exports.authorizeWithUserPass = authorizeWithUserPass;
function authorizeWithRefreshToken(baseUrl, tenant, basicAuthPass, refreshToken) {
    return __awaiter(this, void 0, void 0, function* () {
        let response = null;
        try {
            const req = {
                method: 'post',
                url: `${baseUrl}/auth-oauth2/oauth/token`,
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
                    Authorization: `Basic ${basicAuthPass}`,
                    'X-Tenant': tenant,
                },
                data: `refresh_token=${refreshToken}&grant_type=refresh_token`,
            };
            response = yield axios_1.default(req);
            _authData = response.data;
            tokenRetrieveTimeMs = new Date().getTime();
            return true;
        }
        catch (error) {
            //console.error('Authorization error');
            //console.error(error)
            return false;
        }
    });
}
exports.authorizeWithRefreshToken = authorizeWithRefreshToken;
const authDataProvider = (ctx, refreshTokenProvider, forceRefresh = false) => __awaiter(void 0, void 0, void 0, function* () {
    //TODO: add local state and keep vaild token, minimise calls to auth api
    if (!forceRefresh && _authData && _authData.access_token) {
        // check if we can use current token
        const secondsFromRetrievingExistingToken = new Date().getTime() - tokenRetrieveTimeMs;
        const expiryIfGreaterThan = parseInt(_authData.expires_in) * 1000 * 0.95; //miliseconds
        if (secondsFromRetrievingExistingToken < expiryIfGreaterThan) {
            //tocken is still valid
            console.log(`***** *** USING EXISTING TOKEN (${secondsFromRetrievingExistingToken} ms from retrieving, expires if >${expiryIfGreaterThan}) `);
            //return _authData;
            return { token: _authData.access_token, UUID: _authData.UUID };
        }
    }
    console.log('******** GET AUTH TOKEN (REMOTE CALL) ********');
    let loginSuccess = false;
    const refreshToken = refreshTokenProvider.getRefreshToken();
    if (refreshToken) {
        console.log('*** AUTHORIZE WITH REFRESH TOKEN ');
        loginSuccess = yield authorizeWithRefreshToken(ctx.BASE_URL, ctx.TENANT, ctx.BASIC_AUTH, refreshToken);
    }
    if (!refreshToken || loginSuccess) {
        if (ctx.anonymousAuth) {
            console.log('**** ANONYMOUS AUTH ****');
            loginSuccess = yield authorizeWithUserPass(ctx.BASE_URL, ctx.TENANT, ctx.BASIC_AUTH, 'anonymous', '');
        }
    }
    if (!loginSuccess) {
        return { token: '', UUID: '' };
    }
    else {
        return { token: _authData.access_token, UUID: _authData.UUID };
    }
});
exports.authDataProvider = authDataProvider;
function setAuthData(newAuthData, newTokenRetrieveTimeMs) {
    _authData = newAuthData;
    tokenRetrieveTimeMs = newTokenRetrieveTimeMs;
}
exports.setAuthData = setAuthData;
