"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.postNewOrder = exports.updateCentrallyOrderExtraAttr = exports.pullOrdersForUser = exports.pullOrders = void 0;
const axios_1 = __importDefault(require("axios"));
/**
Pulls open orders for venue. Uses provided access token to authenticate to rest api.
* @param {*} venue - we pull orders for this venue
* @param {*} token - access token
 */
function pullOrders(baseURL, venue, token) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('Pulling orders...');
        let response = null;
        try {
            response = yield axios_1.default({
                method: 'get',
                url: `${baseURL}/ordering-api/api/orders/venue/${venue}`,
                headers: {
                    'Content-Type': 'application/json',
                    Authorization: `Bearer ${token}`,
                },
            });
            const orders = [];
            for (const o of response.data) {
                if (o.completed) {
                    orders.push(o);
                }
            }
            return orders;
        }
        catch (error) {
            console.error(error);
            return [];
        }
    });
}
exports.pullOrders = pullOrders;
/**
Pulls open orders for the user. Uses provided access token to authenticate to rest api.
* @param {*} token - access token
 */
function pullOrdersForUser(baseURL, token) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('Pulling orders for user...');
        let response = null;
        try {
            response = yield axios_1.default({
                method: 'get',
                url: `${baseURL}/ordering-api/api/orders/opened`,
                headers: {
                    'Content-Type': 'application/json',
                    Authorization: `Bearer ${token}`,
                },
            });
            const orders = [];
            for (const o of response.data) {
                if (o.completed) {
                    orders.push(o);
                }
            }
            return orders;
        }
        catch (error) {
            console.error(error);
            return [];
        }
    });
}
exports.pullOrdersForUser = pullOrdersForUser;
function updateCentrallyOrderExtraAttr(baseURL, token, orderId, store) {
    return __awaiter(this, void 0, void 0, function* () {
        let result;
        try {
            result = yield axios_1.default({
                method: 'POST',
                url: `${baseURL}/ordering-api/api/order/${orderId}/extra`,
                headers: {
                    Authorization: `Bearer ${token}`,
                    'Content-Type': 'application/json',
                },
                data: {
                    store,
                },
            });
            return true;
        }
        catch (err) {
            console.log(err);
            return false;
        }
    });
}
exports.updateCentrallyOrderExtraAttr = updateCentrallyOrderExtraAttr;
function postNewOrder(baseURL, token, order) {
    return __awaiter(this, void 0, void 0, function* () {
        const response = yield axios_1.default({
            method: 'post',
            url: `${baseURL}/ordering-api/api/order/new`,
            headers: {
                'Content-Type': 'application/json',
                Authorization: `Bearer ${token}`,
            },
            data: order,
        });
        return response.data;
    });
}
exports.postNewOrder = postNewOrder;
